@@ -71,7 +71,7 @@ typedef enum {
 #define _DEF_ACCX_MEM_HINTS_T
 typedef enum {
   accx_mem_hints_default = 0,     /* runtime decides, can be set with environment variable */
-  accx_mem_hints_disable,         /* memory hints disabled */ 
+  accx_mem_hints_disable,         /* memory hints disabled */
   accx_mem_hints_enable_explicit, /* memory hints enabled at explicit data constructs only */
   accx_mem_hints_enable_all       /* memory hints enabled at explicit and implicit data constructs */
 } accx_mem_hints_t;
@@ -93,8 +93,8 @@ extern "C" {
 /* size_t */
 #include <stdio.h>
 
-void acc_set_default_async(int async);
-int acc_get_default_async(void);
+extern void acc_set_default_async(int async);
+extern int acc_get_default_async(void);
 extern void acc_set_host_only();
 extern int acc_get_num_devices(acc_device_t devtype);
 extern acc_device_t acc_get_device(void);
@@ -105,7 +105,9 @@ extern size_t acc_get_property(int devnum, acc_device_t devtype,
 extern const char *acc_get_property_string(int devnum, acc_device_t devtype,
                                            acc_device_property_t property);
 extern void acc_init(acc_device_t devtype);
+extern void acc_init_device(int devnum, acc_device_t devtype);
 extern void acc_shutdown(acc_device_t devtype);
+extern void acc_shutdown_device(int devnum, acc_device_t devtype);
 extern void acc_set_deviceid(int devid);
 extern int acc_get_deviceid(int devnum, acc_device_t devtype);
 extern int acc_async_test(__PGI_LLONG async);
