@@ -1242,6 +1242,14 @@ pgf90_mvbits(signed char *from, signed char *frompos, signed char *len,
   }
 }
 
+NVHPC_UTILRT_DEV_SIG unsigned long long
+__nvf_global_timer()
+{
+  unsigned long long ret;
+  asm("mov.u64 %0, %globaltimer;" : "=l"(ret));
+  return ret;
+}
+
 #if defined(PGI_COMPILE_BITCODE)
 
 #if defined(__CUDA_ARCH__) && __CUDA_ARCH__ >= 900
